

#include <stdio.h>
#include <stdlib.h>
#include <iostream>
#include <fstream>
#include <string>
#include <string.h>

#include "TTree.h"
#include "TFile.h"
#include "TString.h"

#include "TSystem.h"
#include "THaEvent.h"
#include "THaRun.h"
#include "TH1.h"
#include "TH2.h"
#include "TCanvas.h"
#include "TStyle.h"
#include "TChain.h"
#include "TEllipse.h"
#include "TLine.h"
#include "TMarker.h"
#include "TROOT.h"
#include "TProfile.h"
#include "TF1.h"
#include "TVector3.h"
#include "TVector2.h"
#include "TRotation.h"
#include "TMath.h"
#include "TLegend.h"


using namespace std;

void HallA_style() {

  gROOT->SetStyle("Plain");
  gStyle->SetPaperSize(TStyle::kUSLetter);
  gStyle->SetPaperSize(18,22);
  gStyle->SetOptFit(1111);
  gStyle->SetPalette(1);
  gStyle->SetNdivisions(508);
  
  gStyle->SetCanvasColor(10);
  gStyle->SetPadTopMargin(.05);
  gStyle->SetPadLeftMargin(.15);
  gStyle->SetPadRightMargin(.1);
  gStyle->SetPadBottomMargin(.10);
  gStyle->SetTitleYOffset(1.7);
  gStyle->SetTitleXOffset(1.2);
  gStyle->SetLabelFont(42,"X");
  gStyle->SetLabelFont(42,"Y");

  gStyle->SetTitleX(0.2);
  gStyle->SetTitleW(0.7);
  gStyle->SetTitleFillColor(18);

  // prepare gStyle to be useful
  //   1 = solid
  //   2 = long dash (30 10)
  //   3 = dotted (4 8)
  //   4 = dash-dot (15 12 4 12)
  //   5 = short dash ( 15 15 )
  //   6 = dash-dot-dot 
  gStyle->SetLineStyleString(1,"[]");
  gStyle->SetLineStyleString(2,"[30 10]");
  gStyle->SetLineStyleString(3,"[4 8]");
  gStyle->SetLineStyleString(4,"[15 12 4 12]");
  gStyle->SetLineStyleString(5,"[15 15]");
  gStyle->SetLineStyleString(6,"[15 12 4 12 4 12]");
  gStyle->SetLabelSize(0.04,"X");
  gStyle->SetLabelSize(0.04,"Y");
  gStyle->SetNdivisions(508,"Y");
  gStyle->SetOptDate(0);
  gStyle->SetDateY(.98);
  gStyle->SetStripDecimals(kFALSE);

  gStyle->SetOptStat(0);

}


void DisplayBigBiteScalers(){
  
  HallA_style();

  TChain *t1 = new TChain("EVBBITE");
  t1->Add("./eed_BigBiteScalar_3488.root");
  assert(t1);
  TString name;
  
  Double_t EL[24];
  Double_t ER[24];
  Double_t E[24];
  Double_t dEL[24];
  Double_t dER[24];
  Double_t dE[24];
  Double_t T[8+1];

  for (int i =0; i<24; i++){
    name.Form("E%dL",i+1);
    t1->SetBranchAddress(name.Data(), &EL[i]);
    name.Form("E%dR",i+1);
    t1->SetBranchAddress(name.Data(), &ER[i]);
    name.Form("E%d",i+1);
    t1->SetBranchAddress(name.Data(), &E[i]);
    name.Form("dE%dL",i+1);
    t1->SetBranchAddress(name.Data(), &dEL[i]);
    name.Form("dE%dR",i+1);
    t1->SetBranchAddress(name.Data(), &dER[i]);
    name.Form("dE%d",i+1);
    t1->SetBranchAddress(name.Data(), &dE[i]);
  }

  for (int i =0; i<8; i++){
    name.Form("T%d",i+1);
    t1->SetBranchAddress(name.Data(), &T[i+1]);
  }

  TH2F *hELR[24];
  TH2F *hdELR[24];
  TH1F *hdEL[24];
  TH1F *hdER[24];
  TH1F *hEL[24];
  TH1F *hER[24];
  TH1F *hE[24];
  TH1F *hdE[24];

  for (int i = 0; i<24; i++){
     name.Form("ELR%d",i);
     hELR[i]  = new TH2F(name.Data(), name.Data(), 200,0,1200,200,0,1200);
     name.Form("dELR%d",i);
     hdELR[i]  = new TH2F(name.Data(), name.Data(), 200,0,1200,200,0,1200);
     name.Form("EL%d",i);
     hEL[i]  = new TH1F(name.Data(), name.Data(), 200,0,1200);
     name.Form("ER%d",i);
     hER[i]  = new TH1F(name.Data(), name.Data(), 200,0,1200);
     name.Form("dEL%d",i);
     hdEL[i]  = new TH1F(name.Data(), name.Data(), 200,0,1200);
     name.Form("dER%d",i);
     hdER[i]  = new TH1F(name.Data(), name.Data(), 200,0,1200);
     name.Form("E%d",i);
     hE[i]  = new TH1F(name.Data(), name.Data(), 200,0,1200);
     name.Form("dE%d",i);
     hdE[i]  = new TH1F(name.Data(), name.Data(), 200,0,1200);
  }

  TH1F *hT1 = new TH1F("hT1","BigBite E-trigger",200,0,50000);
  TH1F *hT2 = new TH1F("hT2","BigBite dE-trigger",200,0,50000);
  TH1F *hT3 = new TH1F("hT3","HRS-L main trigger",200,0,50000);

  TH1F *hT4 = new TH1F("hT4","HRS-L sup. trigger",200,0,1200);
  TH1F *hT5 = new TH1F("hT5","Coinc. trigger",200,0,1200);
  TH1F *hT6 = new TH1F("hT6","Coinc. #2 trigger",200,0,1200);
  TH1F *hT7 = new TH1F("hT7","Cosmics trigger",200,0,1200);
  TH1F *hT8 = new TH1F("hT8","1024Hz - clock",200,0,1200);


  int num = t1->GetEntries();
  cout<<"Number of entries : "<<num<<endl;

  for (int i = 0; i<num; i++)
  {
    t1->GetEntry(i);
    if ((i%1000==0) && i>0) cout<<i<<endl; 

     hT1->Fill(T[1]);
     hT2->Fill(T[2]);
     hT3->Fill(T[3]);
     hT4->Fill(T[4]);
     hT5->Fill(T[5]);
     hT6->Fill(T[6]);
     hT7->Fill(T[7]);
     hT8->Fill(T[8]);
   
     
     for (int i =0; i<24; i++){    

       hELR[i]->Fill(EL[i],ER[i]);
       hdELR[i]->Fill(dEL[i],dER[i]);
       hEL[i]->Fill(EL[i]);
       hER[i]->Fill(ER[i]);
       hdEL[i]->Fill(dEL[i]);
       hdER[i]->Fill(dER[i]);
       hE[i]->Fill(E[i]);
       hdE[i]->Fill(dE[i]);
     }

  }

  TCanvas *c1 = new TCanvas("c1","c1",1200,800);
  c1->Divide(4,6);
  for(int i = 0; i<24; i++){
    c1->cd(i+1);
    gStyle->SetPalette(1);
    gPad->SetLogz();
    gPad->SetGrid();
    hELR[i]->Draw("colz");
    hELR[i]->GetXaxis()->SetTitle("R-TDC rate [Hz]");
    hELR[i]->GetYaxis()->SetTitle("L-TDC rate [Hz]");

  }

  TCanvas *c2 = new TCanvas("c2","c2",1200,800);
  c2->Divide(4,6);
  for(int i = 0; i<24; i++){
    c2->cd(i+1);
    gStyle->SetPalette(1);
    gPad->SetLogz();
    gPad->SetGrid();
    hEL[i]->SetLineColor(kRed);
    hEL[i]->Draw("");
    hER[i]->SetLineColor(kGreen);
    hER[i]->Draw("same");
    hE[i]->SetLineColor(kBlue);
    hE[i]->Draw("same");
    hEL[i]->GetXaxis()->SetTitle("TDC rate [Hz]");
    hT8->SetLineColor(kBlack);
    hT8->Draw("same");

  }

  TCanvas *c3 = new TCanvas("c3","c3",1200,800);
  c3->Divide(4,6);
  for(int i = 0; i<24; i++){
    c3->cd(i+1);
    gStyle->SetPalette(1);
    gPad->SetLogz();
    gPad->SetGrid();
    hdEL[i]->SetLineColor(kRed);
    hdEL[i]->Draw("");
    hdER[i]->SetLineColor(kGreen);
    hdER[i]->Draw("same");
    hdE[i]->SetLineColor(kBlue);
    hdE[i]->Draw("same");
    hdEL[i]->GetXaxis()->SetTitle("TDC rate [Hz]");
    hT8->SetLineColor(kBlack);
    hT8->Draw("same");
  }

  
  TCanvas *c4 = new TCanvas("c4","c4",1200,800);
  c4->Divide(2,1);
  c4->cd(1);
  gStyle->SetPalette(1);
  gPad->SetGrid();
  hT1->SetLineColor(1);
  hT1->Draw();
  //gPad->SetLogx();
  hT1->GetYaxis()->SetRangeUser(0,10000);
  hT1->GetXaxis()->SetTitle("Trigger rate [Hz]");
  hT2->SetLineColor(2);
  hT2->Draw("same");
  hT3->SetLineColor(3);
  hT3->Draw("same");

  TLegend *leg1 = new TLegend(0.5, 0.8, 0.88, 0.92);
  leg1->AddEntry(hT1, "BigBite E-plane trigger" ,"L");
  leg1->AddEntry(hT2, "BigBite dE-plane trigger" ,"L");
  leg1->AddEntry(hT3, "HRS-L main trigger" ,"L");
  leg1->Draw();


  c4->cd(2);
  gStyle->SetPalette(1);
  gPad->SetGrid();
  
  hT5->GetYaxis()->SetRangeUser(0,3500);
  hT5->GetXaxis()->SetTitle("Trigger rate [Hz]");
  hT5->SetLineColor(5);
  hT5->Draw();
  hT6->SetLineColor(6);
  hT6->Draw("same");
  hT7->SetLineColor(7);
  hT7->Draw("same");
  hT8->SetLineColor(kBlack);
  hT8->Draw("same");
  hT4->SetLineColor(4);
  hT4->Draw("same");

  TLegend *leg2 = new TLegend(0.4, 0.75, 0.88, 0.92);
  leg2->AddEntry(hT4, "HRS-L supplementary trigger" ,"L");
  leg2->AddEntry(hT5, "Coincidence trigger #1" ,"L");
  leg2->AddEntry(hT6, "Coincidence trigger #2" ,"L");
  leg2->AddEntry(hT7, "Cosmics trigger" ,"L");
  leg2->AddEntry(hT8, "Clock-1024Hz" ,"L");
  leg2->Draw();
  
  
  






}
